<template>
  <SwitchGroup
    as="div"
    class="flex items-center justify-between gap-2"
  >
    <span class="flex flex-grow flex-col overflow-hidden">
      <SwitchLabel
        as="span"
        class="truncate text-sm font-medium leading-6 text-gray-800"
        passive
      >
        {{ $t(label) }}
      </SwitchLabel>
      <SwitchDescription
        as="span"
        class="break-words text-sm text-gray-500"
      >
        {{ $t(description) }}
      </SwitchDescription>
    </span>
    <SwitchInput
      :class="[
        modelValue ? 'bg-primary-500' : 'bg-gray-200',
        'relative inline-flex h-6 w-11 flex-shrink-0 rounded-full border-2 border-transparent transition-colors duration-200 ease-in-out hover:cursor-pointer focus:outline-none focus:ring-2 focus:ring-primary-500 focus:ring-offset-2',
      ]"
      :model-value="modelValue"
      @update:model-value="$emit('update:modelValue', $event)"
    >
      <div
        :class="[
          modelValue ? 'translate-x-5' : 'translate-x-0',
          'pointer-events-none inline-block h-5 w-5 transform rounded-full bg-white shadow ring-0 transition duration-200 ease-in-out',
        ]"
        aria-hidden="true"
      />
    </SwitchInput>
  </SwitchGroup>
</template>

<script lang="ts" setup>
import { Switch as SwitchInput, SwitchDescription, SwitchGroup, SwitchLabel } from "@headlessui/vue";

defineProps<{
  modelValue: boolean;
  label: string;
  description: string;
}>();

defineEmits<{
  "update:modelValue": [value: boolean];
}>();
</script>
